@@ -135,6 +135,72 @@ class Background:
     ##########
     ##########
     ##########
+    def show_1d(self,
+                save=False,savename_prefix='plot',saveformat='eps',
+                params={'figsize':(10,10),
+                        'minmax':(5.,99.),
+                        'cmap':'rainbow',
+                        'fontsize':12,
+                        'tickperx':50,
+                        'color':'red',
+                        'marker':'x',
+                        'ls':':',
+                        'rotation':90.,
+                        'annotate_level':0.
+                       }
+               ):
+        figsize = params['figsize']
+        tickperx = params['tickperx']
+        color = params['color']
+        marker = params['marker']
+        fontsize = params['fontsize']
+        rotation = params['rotation']
+        annotate_level = params['annotate_level']
+        ls = params['ls']
+        minmax = params['minmax']
+        cmap = params['cmap']
+        root = self.data['ROOTNAME']
+        xref = self.trace['XREF']
+        yref = self.trace['YREF']
+        tmp = self.bkg.data['Y'] - self.bkg.model['YFIT']
+        tmpp = tmp.sum(axis=0)
+        m = np.isfinite(tmp)
+        vmin,vmax = np.percentile(tmp[m],minmax[0]),np.percentile(tmp[m],minmax[1])
+        fig = plt.figure(figsize=figsize)
+        ax = fig.add_subplot(2,1,1)
+        ax.imshow(tmp,origin='lower',cmap=cmap,vmin=vmin,vmax=vmax)
+        ax.set_title('{0}_bkgsub'.format(root),fontsize=fontsize)
+        ax.set_ylabel('pixY - {0}'.format(int(yref)),fontsize=fontsize)
+        ax = fig.add_subplot(2,1,2,sharex=ax)
+        ax.plot(tmpp)
+        tmpx = np.arange(tmpp.shape[0])
+        tmpy = np.full_like(tmpx,annotate_level,dtype=float)
+        ww = self.bbox['bbox']['WW']
+        ax.plot(tmpx,tmpy,color=color,ls=ls)
+        for i,ii in enumerate(tmpx):
+            if (i in {0,len(tmpx)-1}) or (np.mod(i,tickperx)==0):
+                label = '{0}A'.format(int(ww[i]))
+                ax.plot(tmpx[i],tmpy[i],color=color,marker=marker)
+                ax.annotate(label,(tmpx[i],tmpy[i]),
+                             textcoords='offset points',
+                             xytext=(0,10),
+                             ha='center',
+                             fontsize=fontsize,
+                             rotation=rotation,
+                             color=color
+                            )
+        ax.set_frame_on(False)
+        ax.grid()
+        ax.set_ylabel('cps',fontsize=fontsize)
+        ax.set_xlabel('pixX - {0}'.format(int(xref)),fontsize=fontsize)
+        fig.tight_layout()
+        if save:
+            string = '{0}_1d.{1}'.format(savename_prefix,saveformat)
+            fig.savefig(string,format=saveformat,bbox_inches='tight')
+            print('Save {0}'.format(string))
+    ##########
+    ##########
+    ##########
     def show_bkg2dsub(self,
                       save=False,savename_prefix='plot',saveformat='eps',
                       params={'figsize':(30,10),
